@@ -46,6 +46,8 @@
 "XVkbd*shadowWidth: 2",
 "XVkbd*Label.shadowWidth: 0",
 "XVkbd*MainMenu.shadowWidth: 0",
+"XVkbd*MainMenu.topShadowContrast: 0",
+"XVkbd*MainMenu.bottomShadowContrast: 0",
 "XVkbd*Background: gray85",
 "XVkbd*Text*background: white",
 "XVkbd*specialBackground: gray75",
@@ -59,8 +61,8 @@
 "XVkbd*defaultDistance: 0",
 "XVkbd*Form.borderWidth: 0",
 "XVkbd*Label.borderWidth: 0",
-"XVkbd*Command.internalWidth: 1",
-"XVkbd*Repeater.internalWidth: 1",
+"XVkbd*Command.internalWidth: 2",
+"XVkbd*Repeater.internalWidth: 2",
 "XVkbd*Command.resize: false",
 "XVkbd*Repeater.resize: false",
 "XVkbd*Command.justify: center",
@@ -121,16 +123,30 @@
 "XVkbd*menu.edit_fkey.label: Edit Function Keys...",
 "XVkbd*menu.show_keypad.label: Show Keypad?",
 "XVkbd*menu.show_functionkey.label: Show Function Keys?",
-"XVkbd*menu.use_xtest.label: Use XTEST Extension?",
-"XVkbd*menu.always_on_top.label: Always on Top?",
-"XVkbd*menu.shift_lock.label: Lock Shift?",
-"XVkbd*menu.altgr_lock.label: Lock AltGr?",
-"XVkbd*menu.modifiers_lock.label: Lock Control, Alt and Meta?",
-"XVkbd*menu.quick_modifiers.label: Enable \"Quick Modifiers\"?",
+"XVkbd*menu.props.label: Property...",
 "XVkbd*menu.open_display.label: Connect to Remote Display...",
 "XVkbd*menu.close_display.label: Revert to Local Display",
 "XVkbd*menu.quit.label: Quit",
 "XVkbd*menu.SmeBSB.rightMargin: 30",
+"XVkbd*props_panel.title: xvkbd - proprety",
+"XVkbd*props_panel*defaultDistance: 10",
+"XVkbd*props_panel*vertDistance: 5",
+"XVkbd*props_panel*always_on_top.label: Always on Top?",
+"XVkbd*props_panel*shift_lock.label: Lock Shift?",
+"XVkbd*props_panel*altgr_lock.label: Lock AltGr?",
+"XVkbd*props_panel*modifiers_lock.label: Lock Control, Alt and Meta?",
+"XVkbd*props_panel*quick_modifiers.label: Enable \"Quick Modifiers\"?",
+"XVkbd*props_panel*use_xtest.label: Use XTEST Extension?",
+"XVkbd*props_panel*jump_pointer.label: Jump Pointer?",
+"XVkbd*props_panel*click.label: Key-Click Sound:",
+"XVkbd*props_panel*autoclick.label: Automatic Click:",
+"XVkbd*props_panel*dismiss.label: Dismiss",
+"XVkbd*props_panel*dismiss.internalWidth: 4",
+"XVkbd*props_panel*dismiss.width: 0",
+"XVkbd*props_panel*dismiss.height: 0",
+"XVkbd*props_panel*dismiss.vertDistance: 10",
+"XVkbd*props_panel*Toggle.width: 200",
+"XVkbd*props_panel*Toggle.justify: left",
 "XVkbd.about_panel.title: xvkbd - about this program",
 "XVkbd.keypad_panel.title: xvkbd - keypad",
 "XVkbd.sun_fkey_panel.title: xvkbd - Sun",
@@ -191,7 +207,7 @@
 "XVkbd*edit_fkey_panel*fkey_value_sep.fromHoriz: fkey_value_menu",
 "XVkbd*edit_fkey_panel*fkey_value.fromHoriz: fkey_value_sep",
 "XVkbd*edit_fkey_panel*fkey_value.width: 200",
-"XVkbd*edit_fkey_panel*fkey_value.height: 18",
+"XVkbd*edit_fkey_panel*fkey_value.height: 22",
 "XVkbd*edit_fkey_panel*save_button.fromVert: form2",
 "XVkbd*edit_fkey_panel*close_button.fromVert: form2",
 "XVkbd*edit_fkey_panel*close_button.fromHoriz: save_button",
@@ -225,7 +241,7 @@
 "XVkbd*deadkey_panel*dead_abovedot.label: \\267",
 "XVkbd.customizations: default,belgian,danish,fitaly,french,french2,\
   german,greek,hebrew,icelandic,italian,jisx6002/ja,jisx6004/ja,korean/ko_KR.eucKR,\
-  norwegian,portuguese,slovene,spanish,swedish,swissgerman,turkish,uk,latin1",
+  norwegian,portuguese,russian/ru_RU.KOI8-R,slovene,spanish,swedish,swissgerman,turkish,uk,latin1",
 "XVkbd*layout_panel*default.label: Default",
 "XVkbd*layout_panel*belgian.label: Belgian",
 "XVkbd*layout_panel*danish.label: Danish",
@@ -242,6 +258,7 @@
 "XVkbd*layout_panel*korean.label: Korean",
 "XVkbd*layout_panel*norwegian.label: Norwegian",
 "XVkbd*layout_panel*portuguese.label: Portuguese",
+"XVkbd*layout_panel*russian.label: Russian",
 "XVkbd*layout_panel*slovene.label: Slovene",
 "XVkbd*layout_panel*spanish.label: Spanish",
 "XVkbd*layout_panel*swedish.label: Swedish",
