@@ -90,6 +90,10 @@ struct appres_struct {
 
   float max_width_ratio;
   float max_height_ratio;
+  int text_delay;
+  int key_click_pitch;
+  int key_click_duration;
+  int autoclick_delay;
 } appres;
 
 
